@@ -3,10 +3,10 @@
 use strict;
 use warnings;
 
-use oEdtk::EDM qw(edm_process_zip);
+use oEdtk::EDMS qw(EDMS_process_zip);
 
 if (@ARGV < 2) {
 	die "Usage: $0 <ged.zip> <outdir>\n";
 }
 
-edm_process_zip($ARGV[0], $ARGV[1]);
+EDMS_process_zip($ARGV[0], $ARGV[1]);
